# pyrtz

Analysis of AFM force curves in Python.

Developed at the University of Iowa Institute for Vision Research https://ivr.uiowa.edu/

# Installation
pyrtz is on PyPI. Install using pip (Python version >= 3.8.0 is required)

```
pip install pyrtz
```
